[PATCH 1 of 2] context: use correct spelling of committable

Sean Farley sean.michael.farley at gmail.com
Wed Sep 18 12:45:05 CDT 2013


# HG changeset patch
# User Sean Farley <sean.michael.farley at gmail.com>
# Date 1379460885 18000
#      Tue Sep 17 18:34:45 2013 -0500
# Node ID 8d2673f1a09470805ff366586254c689f809254f
# Parent  1abd45e2553a9e5d03efd6fa4372b4599d361a65
context: use correct spelling of committable

diff --git a/mercurial/context.py b/mercurial/context.py
--- a/mercurial/context.py
+++ b/mercurial/context.py
@@ -819,12 +819,12 @@
         # hard for renames
         c = self._filelog.children(self._filenode)
         return [filectx(self._repo, self._path, fileid=x,
                         filelog=self._filelog) for x in c]
 
-class commitablectx(basectx):
-    """A commitablectx object provides common functionality for a context that
+class committablectx(basectx):
+    """A committablectx object provides common functionality for a context that
     wants the ability to commit, e.g. workingctx or memctx."""
     def __init__(self, repo, text="", user=None, date=None, extra=None,
                  changes=None):
         self._repo = repo
         self._rev = None
@@ -1060,11 +1060,11 @@
         self._repo.dirstate.setparents(node)
 
     def dirs(self):
         return self._repo.dirstate.dirs()
 
-class workingctx(commitablectx):
+class workingctx(committablectx):
     """A workingctx object makes access to data related to
     the current working directory convenient.
     date - any valid date string or (unixtime, offset), or None.
     user - username string, or None.
     extra - a dictionary of extra values, or None.
@@ -1186,12 +1186,12 @@
                     self._repo.dirstate.add(dest)
                 self._repo.dirstate.copy(source, dest)
             finally:
                 wlock.release()
 
-class commitablefilectx(basefilectx):
-    """A commitablefilectx provides common functionality for a file context that
+class committablefilectx(basefilectx):
+    """A committablefilectx provides common functionality for a file context that
     wants the ability to commit, e.g. workingfilectx or memfilectx."""
     def __init__(self, repo, path, filelog=None, ctx=None):
         self._repo = repo
         self._path = path
         self._changeid = None
@@ -1227,11 +1227,11 @@
                 for p, n, l in pl if n != nullid]
 
     def children(self):
         return []
 
-class workingfilectx(commitablefilectx):
+class workingfilectx(committablefilectx):
     """A workingfilectx object makes access to data related to a particular
        file in the working directory convenient."""
     def __init__(self, repo, path, filelog=None, workingctx=None):
         super(workingfilectx, self).__init__(repo, path, filelog, workingctx)
 


More information about the Mercurial-devel mailing list